Packed

Enum Packed 

pub enum Packed {
Show 16 variants Int(BigInt), Float(f64), Decimal(BigDecimal), Str(String), Bytes(Vec<u8>), Bool(bool), None, List(Vec<Packed>), Dict(Vec<(String, Packed)>), Object { class_id: u32, class_name: String, fields: Vec<(String, Packed)>, }, Function { fn_id: u32, name: String, captures: Vec<Packed>, }, Class { fn_id: u32, name: String, }, BoundMethod { receiver: Box<Packed>, method: String, }, Error { kind: ErrorKind, message: String, file: String, line: u32, }, Socket(SocketState), Bowl(BowlHandle),
}
An owned, Send mirror of a Value, holding no Rc so it can move to another thread. Built by pack_value, consumed by unpack_packed.

Variants



Int(BigInt)



Float(f64)



Decimal(BigDecimal)



Str(String)



Bytes(Vec<u8>)



Bool(bool)



None



List(Vec<Packed>)



Dict(Vec<(String, Packed)>)



Object

Fields

class_id: u32
class_name: String
fields: Vec<(String, Packed)>


Function

Fields

fn_id: u32
name: String
captures: Vec<Packed>


Class

Fields

fn_id: u32
name: String


BoundMethod

Fields

receiver: Box<Packed>
method: String


Error

Fields

message: String
file: String
line: u32


Socket(SocketState)



Bowl(BowlHandle)