pub fn fetch_append(path: &Value, text: &Value) -> DogeResultExpand description
fetch.append(path, text) — add text to the end of the file, creating it if
needed. Returns none.
pub fn fetch_append(path: &Value, text: &Value) -> DogeResultfetch.append(path, text) — add text to the end of the file, creating it if
needed. Returns none.