pub fn fetch_copy(from: &Value, to: &Value) -> DogeResultExpand description
fetch.copy(from, to) — copy the contents of file from to to, creating or
replacing to. A missing from is a catchable IOError. Returns none.
pub fn fetch_copy(from: &Value, to: &Value) -> DogeResultfetch.copy(from, to) — copy the contents of file from to to, creating or
replacing to. A missing from is a catchable IOError. Returns none.