pub fn fetch_list(path: &Value) -> DogeResultExpand description
fetch.list(path) — the names of the entries in directory path, sorted so the
order is stable across runs. A missing path or one that is not a directory is a
catchable IOError.
pub fn fetch_list(path: &Value) -> DogeResultfetch.list(path) — the names of the entries in directory path, sorted so the
order is stable across runs. A missing path or one that is not a directory is a
catchable IOError.