pub fn fetch_read(path: &Value) -> DogeResultExpand description
fetch.read(path) — the file’s whole contents as a Str. A missing file or one
whose bytes are not valid text is a catchable IOError.
pub fn fetch_read(path: &Value) -> DogeResultfetch.read(path) — the file’s whole contents as a Str. A missing file or one
whose bytes are not valid text is a catchable IOError.