gib

Function gib 

pub fn gib(prompt: Option<&Value>) -> DogeResult
gib() / gib("prompt") — read one line from standard input. An optional prompt, which must be a Str, is written without a trailing newline and flushed first. The returned Str has its trailing newline stripped; at end of input the result is none. A stdin read failure is a catchable IOError.