pub fn howl_accept(listener: &Value) -> DogeResultExpand description
howl.accept(listener) — block until a client connects, then return the new
connection. A non-listener socket is a catchable TypeError; a closed one is an
IOError.
pub fn howl_accept(listener: &Value) -> DogeResulthowl.accept(listener) — block until a client connects, then return the new
connection. A non-listener socket is a catchable TypeError; a closed one is an
IOError.