hunt_replace

Function hunt_replace 

pub fn hunt_replace(pat: &Value, text: &Value, repl: &Value) -> DogeResult
hunt.replace(pat, text, repl) — every match of pat in text swapped for repl, where repl may reference capture groups as $1 or ${name}.