pack_sniff

Function pack_sniff 

pub fn pack_sniff(bowl: &Value) -> DogeResult
pack.sniff(bowl) — block until a value arrives in the bowl, then return it. A bowl that is empty and can never receive another value again (every writer is gone) is a catchable IOError rather than a forever-block. A non-bowl handle is a catchable type error.