pub fn rem(a: Value, b: Value) -> DogeResultExpand description
% — modulo whose result takes the sign of the divisor (Python-style), so
that a == (a // b) * b + (a % b) holds.
pub fn rem(a: Value, b: Value) -> DogeResult% — modulo whose result takes the sign of the divisor (Python-style), so
that a == (a // b) * b + (a % b) holds.