strings_index

Function strings_index 

pub fn strings_index(s: &Value, sub: &Value) -> DogeResult
strings.index(s, sub) — the character offset of the first sub in s, or -1 when absent. Char-based like every Str operation: str::find returns a byte position, so it is converted to a character count.