strings_split

Function strings_split 

pub fn strings_split(s: &Value, sep: &Value) -> DogeResult
strings.split(s, sep) — a List of the pieces of s between each sep. Empty pieces are kept ("a,,b" splits into three); splitting on an empty separator is a catchable ValueError.