to_float

Function to_float 

pub fn to_float(v: &Value) -> DogeResult
float(x) — Int and Bool widen to Float, Decimal rounds to the nearest Float, Float is unchanged, a numeric Str is parsed. A non-numeric Str is a catchable ValueError; other types are a TypeError.