pub fn chase_run(cmd: &Value, args: &Value, stdin: &Value) -> DogeResultExpand description
chase.run(cmd, args, stdin) — run cmd with the Str args, feeding it the
Str stdin (or nothing when stdin is none), and give back a Dict
{"code": Int, "stdout": Str, "stderr": Str}. Failing to launch the program,
or output that is not valid text, is a catchable IOError.