fetch_list

Function fetch_list 

pub fn fetch_list(path: &Value) -> DogeResult
fetch.list(path) — the names of the entries in directory path, sorted so the order is stable across runs. A missing path or one that is not a directory is a catchable IOError.