pub fn fetch_make_dir(path: &Value) -> DogeResultExpand description
fetch.make_dir(path) — create the directory at path, along with any missing
parent directories. Doing this when the directory already exists is not an
error. Returns none.
pub fn fetch_make_dir(path: &Value) -> DogeResultfetch.make_dir(path) — create the directory at path, along with any missing
parent directories. Doing this when the directory already exists is not an
error. Returns none.