pub fn fetch_stat(path: &Value) -> DogeResultExpand description
fetch.stat(path) — metadata about path as a Dict with size (Int bytes),
modified (Float unix seconds, negative for a pre-epoch time), and is_dir
(Bool). A missing path, or a platform that cannot report the modified time, is a
catchable IOError.