pub fn hunt_replace(pat: &Value, text: &Value, repl: &Value) -> DogeResultExpand description
hunt.replace(pat, text, repl) — every match of pat in text swapped for
repl, where repl may reference capture groups as $1 or ${name}.
pub fn hunt_replace(pat: &Value, text: &Value, repl: &Value) -> DogeResulthunt.replace(pat, text, repl) — every match of pat in text swapped for
repl, where repl may reference capture groups as $1 or ${name}.