pub fn object_class_id(recv: &Value) -> DogeResult<u32>Expand description
The class id of a method-call receiver, so the dispatcher can pick the right
arm. Calling a method on a value that has no methods is a catchable
AttrError.
pub fn object_class_id(recv: &Value) -> DogeResult<u32>The class id of a method-call receiver, so the dispatcher can pick the right
arm. Calling a method on a value that has no methods is a catchable
AttrError.