pub fn pack_fetch(pup: &Value) -> DogeResultExpand description
pack.fetch(pup) — wait for a pup to finish and return its function’s result,
or re-raise (catchably) the error the pup hit, with the pup’s own file/line
preserved. Fetching a pup twice, or a value that is not a pup, is a catchable
error.