pub fn strings_index(s: &Value, sub: &Value) -> DogeResultExpand description
strings.index(s, sub) — the character offset of the first sub in s, or
-1 when absent. Char-based like every Str operation: str::find returns a
byte position, so it is converted to a character count.