pub fn to_float(v: &Value) -> DogeResultExpand description
float(x) — Int and Bool widen to Float, Float is unchanged, a numeric Str
is parsed. A non-numeric Str is a catchable ValueError; other types are a
TypeError.
pub fn to_float(v: &Value) -> DogeResultfloat(x) — Int and Bool widen to Float, Float is unchanged, a numeric Str
is parsed. A non-numeric Str is a catchable ValueError; other types are a
TypeError.